# Correct kernel header problems

# It seems that 2.6.28 serie (or a version greater than 2.6.24 that, according to Intel notes, is the greater one supported by VTune) lacks ${your kernel source}/include/asm/*.h links to ${kernel source}/arch/${your arch}/include/asm/*.h headers.
# http://ubuntuforums.org/archive/index.php/t-466019.html

#!/bin/bash
set_variables()
{
#VTUNE_MOD_SRC=/opt/intel/vtune/vdk/src
KERNEL_CUSTOM_VERSION=$(uname -r)
KERNEL_SRC=/lib/modules/${KERNEL_CUSTOM_VERSION}/build
KERNEL_VERSION=$(grep UTS_RELEASE ${KERNEL_SRC}/include/linux/utsrelease.h | cut -f2 -d\")
ARCH=$(readlink ${KERNEL_SRC}/include/asm | cut -f2 -d-)
}

echo "Setting variables..."
set_variables
echo "KERNEL_CUSTOM_VERSION=${KERNEL_CUSTOM_VERSION}"
echo "KERNEL_SRC=${KERNEL_SRC}"
echo "KERNEL_VERSION=${KERNEL_VERSION}"
echo "ARCH=${ARCH}"


echo "Creating fixed include/asm link..."
cd ${KERNEL_SRC}/include
rm -f asm
ln -s ../arch/${ARCH}/include/asm asm

echo "Restoring original include/asm files..."
cp ${KERNEL_SRC}/include/asm-${ARCH}/*\.h ${KERNEL_SRC}/include/asm/

#echo "Building vtune module..."
#cd $VTUNE_MOD_SRC
#./build-driver --kernel-version=${KERNEL_VERSION}

#echo "Fixing module name..."
module=$(ls *.ko)
#ln -s ${module} $(echo ${module} | sed -e "s|${KERNEL_VERSION}|${KERNEL_CUSTOM_VERSION}|")

echo "Done."
